@@ -5,11 +5,10 @@ use crate::{
     KeyFingerprint, Prefix, PrivateKey, PrivateKeyBytes, PublicKey, Result, KEY_SIZE,
 };
 use core::{
-    convert::{TryFrom, TryInto},
     fmt::{self, Debug},
     str::FromStr,
 };
-use hmac::{Mac, NewMac};
+use hmac::Mac;
 use subtle::{Choice, ConstantTimeEq};
 use zeroize::Zeroize;
 
