@@ -4,11 +4,8 @@ use crate::{
     ChildNumber, Error, ExtendedKey, ExtendedKeyAttrs, ExtendedPrivateKey, HmacSha512,
     KeyFingerprint, Prefix, PrivateKey, PublicKey, PublicKeyBytes, Result, KEY_SIZE,
 };
-use core::{
-    convert::{TryFrom, TryInto},
-    str::FromStr,
-};
-use hmac::{Mac, NewMac};
+use core::str::FromStr;
+use hmac::Mac;
 
 #[cfg(feature = "alloc")]
 use alloc::string::{String, ToString};
