@@ -1,8 +1,7 @@
 //! Trait for deriving child keys on a given type.
 
 use crate::{KeyFingerprint, PrivateKeyBytes, Result, KEY_SIZE};
-use core::convert::TryInto;
-use ripemd160::Ripemd160;
+use ripemd::Ripemd160;
 use sha2::{Digest, Sha256};
 
 #[cfg(feature = "secp256k1")]
@@ -54,7 +53,10 @@ impl PublicKey for k256::PublicKey {
     }
 
     fn derive_child(&self, other: PrivateKeyBytes) -> Result<Self> {
-        let child_scalar = k256::NonZeroScalar::from_repr(other.into()).ok_or(Error::Crypto)?;
+        let child_scalar =
+            Option::<k256::NonZeroScalar>::from(k256::NonZeroScalar::from_repr(other.into()))
+                .ok_or(Error::Crypto)?;
+
         let child_point = self.to_projective() + (k256::AffinePoint::generator() * *child_scalar);
         Self::from_affine(child_point.into()).map_err(|_| Error::Crypto)
     }
